🌐 ipify API

A simple public IP address API, easy to integrate into any application in seconds. (Source)
Installation
To install the library, use the following command:
go get github.com/go-api-libs/ipify/pkg/ipify
Usage
Example: Get you public IP address
package main
import (
"context"
"github.com/go-api-libs/ipify/pkg/ipify"
)
func main() {
c, err := ipify.NewClient()
if err != nil {
panic(err)
}
ctx := context.Background()
ipWrapper, err := c.GetIP(ctx, &ipify.GetIPParams{Format: "json"})
if err != nil {
panic(err)
}
// Use ipWrapper object
}
Contributing
If you have any contributions to make, please submit a pull request or open an issue on the GitHub repository.
License
This project is licensed under the MIT License. See the LICENSE file for details.